@@ -7,16 +7,24 @@ from django.utils.module_loading import import_string
 from django.utils.deprecation import MiddlewareMixin
 from django.contrib.auth import BACKEND_SESSION_KEY
 from django.utils.functional import cached_property
+from django.contrib.auth import get_user_model
+from django.http import HttpResponseRedirect
 from django.conf import settings
 from django.contrib import auth
+from django.urls import reverse
 
+import requests
 from mozilla_django_oidc.middleware import SessionRefresh as SessionRefreshOIDC
 from mozilla_django_oidc.auth import OIDCAuthenticationBackend
 from mozilla_django_oidc.utils import absolutify
+from dnoticias_services.authentication.keycloak import (
+    get_user_keycloak_info,
+)
 
-from .utils import generate_oidc_cookies, get_cookie_equivalency
+from .utils import generate_oidc_cookies, get_cookie_equivalency, get_cookie_configuration
 from .backends import ExtraClaimsOIDCAuthenticationBackend
 
+User = get_user_model()
 logger = logging.getLogger(__name__)
 
 
@@ -149,9 +157,7 @@ class LoginMiddleware(BaseAuthMiddleware, MiddlewareMixin):
 
 
 class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
-    """
-    Just generates the cookie if the user is logged in
-    """
+    """Just generates the cookie if the user is logged in"""
     def __init__(self, get_response):
         self.get_response = get_response
 
@@ -161,7 +167,77 @@ class TokenMiddleware(BaseAuthMiddleware, MiddlewareMixin):
             request.user.is_authenticated
         )
 
+    def _can_check_dcs_session(self, request):
+        """Check if the request requires to check the sessionid on dcs
+        
+        :param request: httpRequest
+        ...
+        :return: True if the request if processable and the function proceeds to check the ssid
+        """
+        return (
+            not any(pat.match(request.path) for pat in self.exempt_url_patterns)\
+            and not request.user.is_authenticated\
+            and request.COOKIES.get("sessionid")
+        )
+
+    def __is_user_migrated(self, email: str) -> bool:
+        """Check on keycloak if the user has been migrated
+        :param email: The user email that we will verify if has been migrated
+        ...
+        :return: True if the user has been migrated
+        """
+        user_info = get_user_keycloak_info(email)
+        return bool(user_info.get("attributes", {}).get("user_migrated", False))
+
+    def check_dcs_cookies(self, request, http_response):
+        """Check the dcs cookies and redirects to password reset view
+        
+        :param request: httpRequest
+        :param http_response: httpResponse
+        ...
+        :return: httpResponse
+        """
+        cookies = request.COOKIES
+        session_id = cookies.get("sessionid")
+        dcs_session_api = settings.DCS_SESSION_MIGRATE_API_URL
+
+        # If we dont have a session_id cookie, we just return the initial response
+        if not session_id:
+            return http_response
+
+        # We ask to the DCS the email associated to that session_id. This returns an email if the
+        # sessionid is not anon, the user does not have @dnoticias.pt in his email and is not part
+        # of the staff or superuser.
+        response = requests.post(dcs_session_api, {"session_id": session_id})
+        body = response.json()
+        logger.info("[DCS Session] Returned %s", body)
+
+        if response.status_code == 200:
+            if not body.get("error"):
+                # Gets the email from body
+                email = body.get("email")
+
+                if not self.__is_user_migrated(email):
+                    # We make an HttpResponseRedirect to the change password view
+                    http_response = HttpResponseRedirect(reverse("password-recovery"))
+
+                    request.session["migration_email"] = email
+                    request.session["migration_next_url"] = request.build_absolute_uri()
+                    request.session.save()
+
+                # Deletes the sessionid cookie
+                extra_data = get_cookie_configuration()
+                extra_data.pop('expires')
+                extra_data.pop('secure')
+                extra_data.pop('httponly')
+                http_response.delete_cookie('sessionid', **extra_data)
+
+        return http_response
+
     def process_response(self, request, response):
+        if self._can_check_dcs_session(request):
+            response = self.check_dcs_cookies(request, response)
+
         # If the user is logged in then we set the cookies, else we delete it
         if self._is_processable(request):
             response = generate_oidc_cookies(request.session, response)
