@@ -4,14 +4,16 @@ from django.views.decorators.clickjacking import xframe_options_exempt
 from django.http.response import HttpResponseRedirect
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
-from django.views.generic import View
-from django.shortcuts import render
+from django.views.generic import View, FormView
+from django.shortcuts import render, redirect
+from django.urls import reverse_lazy
 from django.conf import settings
+from django.http import Http404
 
 from mozilla_django_oidc.views import OIDCLogoutView, OIDCAuthenticationCallbackView
 
-
 from .utils import delete_user_sessions, get_cookie_equivalency
+from .forms import PasswordRecoveryDCSForm
 from .redis import KeycloakSessionStorage
 
 logger = logging.getLogger(__name__)
@@ -102,3 +104,51 @@ class DnoticiasOIDCAuthenticationCallbackView(OIDCAuthenticationCallbackView):
             logger.exception("Something wrong was happened :(")
 
         return response
+
+
+class ApplicationDataView(View):
+    template_name = "authentication/app-data.html"
+
+    def get(self, request, *args, **kwargs):
+        next_url = request.GET.get("next_url")
+
+        access_token = request.session.get("oidc_access_token")
+        refresh_token = request.session.get("oidc_refresh_token")
+        access_token_expires_in = request.session.get("oidc_expires_in")
+        refresh_token_expires_in = request.session.get("oidc_refresh_expires_in")
+
+        return render(request, self.template_name, locals())
+
+
+class PasswordRecoveryDCSFormView(FormView):
+    template_name = "authentication/password-recovery.html"
+    form_class = PasswordRecoveryDCSForm
+
+    def dispatch(self, request, *args, **kwargs):
+        if not request.session.get("migration_email"):
+            raise Http404()
+
+        return super().dispatch(request, *args, **kwargs)
+
+    def get_success_url(self):
+        next_url = self.request.session.get("migration_next_url")
+        login_url = reverse_lazy("oidc_authentication_init")
+        return f"{login_url}?next_url={next_url}"
+
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        context["password_recovery_url"] = \
+            f"{settings.OIDC_RESET_PASSWORD_URL}?next={self.request.session.get('migration_next_url')}"
+        return context
+
+    def get_form_kwargs(self):
+        kwargs = super().get_form_kwargs()
+        kwargs["email"] = self.request.session.get("migration_email")
+        return kwargs
+
+    def form_valid(self, form):
+        form.save()
+        return super().form_valid(form)
+
+    def form_invalid(self, form):
+        return super().form_invalid(form)
